--[[
Copyright 2013 João Cardoso
PetTracker Broker is distributed under the terms of the GNU General Public License (Version 3).
As a special exception, the copyright holders of this addon do not give permission to
redistribute and/or modify it.

This addon is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the addon. If not, see <http://www.gnu.org/licenses/gpl-3.0.txt>.

This file is part of PetTracker Broker.
--]]

local ADDON = ...
local Addon = PetTracker
local Tip = CreateFrame('Frame', ADDON .. 'Tip', UIParent, 'GameTooltipTemplate')
local Broker = Addon:NewModule('Broker', LibStub('LibDataBroker-1.1'):NewDataObject('PetTracker', {
	type = 'data source',
	icon = 'Interface/Icons/Tracking_WildPet',
	label = PETS
}))


--[[ Addon Events ]]--

function Broker:Startup()
	local header = _G[ADDON .. 'TipTextLeft1']
	header:SetTextColor(PASSIVE_SPELL_FONT_COLOR.r, PASSIVE_SPELL_FONT_COLOR.g, PASSIVE_SPELL_FONT_COLOR.b)
	header:SetText(Addon.Locals.BattlePets)
	header:Show()

	local tracker = Addon.Tracker(Tip)
	tracker:SetSize(1, 1)
	tracker:SetPoint('TOPLEFT', 15, -30)
	tracker.ShowSpecies = function()
		tracker.__index.ShowSpecies(tracker)
		Tip:SetHeight(tracker:Count() * 20 + 65)
	end

	self.tracker = tracker
	Tip:SetSize(265, 1)
end

function Broker:TrackingChanged()
	local progress = Addon.Journal:GetCurrentProgress()
	local owned = 0

	for i = Addon.MaxQuality, 1, -1 do
		owned = owned + progress[i].total
	end

	self.text = owned .. '/' .. progress.total
	self.tracker:Update()
end


--[[ Frame Events ]]--

function Broker:OnEnter()
	Tip:ClearAllPoints()
	Tip:Show()

	if (self:GetBottom() < UIParent:GetHeight() / 2) then
		Tip:SetPoint('BOTTOM', self, 'TOP')
	else
		Tip:SetPoint('TOP', self, 'BOTTOM')
	end

end

function Broker:OnLeave()
	Tip:Hide()
end

function Broker:OnClick(button)
	if button == 'RightButton' then
		Addon.Tracker.ToggleOptions(self)
	else
		Addon.Tracker:Toggle()
	end
end